src/hg/hgTracks/hgTracks.h 1.188

1.188 2009/11/01 19:46:04 aamp
Just variable name changes. s/nextPrevItem/nextPrevExon/ and s/labelNextPrevItem/nextPrevItem/.
Index: src/hg/hgTracks/hgTracks.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTracks/hgTracks.h,v
retrieving revision 1.187
retrieving revision 1.188
diff -b -B -U 4 -r1.187 -r1.188
--- src/hg/hgTracks/hgTracks.h	16 Oct 2009 00:34:30 -0000	1.187
+++ src/hg/hgTracks/hgTracks.h	1 Nov 2009 19:46:04 -0000	1.188
@@ -174,10 +174,10 @@
     int sourceRightPixels;	/* Number of pixels to right we'll need. */
 
     boolean exonArrows;	/* Draw arrows on exons? */
     boolean exonArrowsAlways;	/* Draw arrows on exons even with introns showing? */
-    boolean nextItemButtonable; /* Use the next-exon buttons? */
-    boolean labelNextItemButtonable; /* Use the next-gene buttons? */
+    boolean nextExonButtonable; /* Use the next-exon buttons? */
+    boolean nextItemButtonable; /* Use the next-gene buttons? */
     struct itemAttrTbl *itemAttrTbl;  /* relational attributes for specific
                                          items (color) */
 
     /* fill in left label drawing area */
@@ -191,20 +191,20 @@
                                 loaded and drawn by this track.  This
                                 is used for "composite" tracks, such
                                 as "mafWiggle */
 
-    void (*nextPrevItem)(struct track *tg, struct hvGfx *hvg, void *item, int x, int y, int w, int h, boolean next);
+    void (*nextPrevExon)(struct track *tg, struct hvGfx *hvg, void *item, int x, int y, int w, int h, boolean next);
     /* Function will draw the button on a track item and assign a map */
     /* box to it as well, so that a click will move the browser window */
     /* to the next (or previous if next==FALSE) item. This is meant to */
     /* jump to parts of an item already partially in the window but is */
     /* hanging off the edge... e.g. the next exon in a gene. */
 
-    void (*labelNextPrevItem)(struct track *tg, boolean next);
+    void (*nextPrevItem)(struct track *tg, boolean next);
     /* If this function is given, it can dictate where the browser loads */
     /* up based on whether a next-item button on the longLabel line of */
     /* the track was pressed (as opposed to the next-item buttons on the */
     /* track items themselves... see nextPrevItem() ). This is meant for */
     /* going to the next/previous item currently unseen in the browser, */
     /* e.g. the next gene. SO FAR THIS IS UNIMPLEMENTED. */
 
@@ -191,20 +191,20 @@
     /* up based on whether a next-item button on the longLabel line of */
     /* the track was pressed (as opposed to the next-item buttons on the */
-    /* track items themselves... see nextPrevItem() ). This is meant for */
+    /* track items themselves... see nextPrevExon() ). This is meant for */
     /* going to the next/previous item currently unseen in the browser, */
     /* e.g. the next gene. SO FAR THIS IS UNIMPLEMENTED. */
     char *(*itemDataName)(struct track *tg, char *itemName);